@@ -159,6 +159,15 @@ class ContentLengthError(requests.HTTPError):
     '''Will be raised when actual content length received from server does not match the "Content-Length" header'''
     pass
 
+
+def format_exception(e):
+    """Returns a string containing the type and text of the exception.
+
+    """
+    from .utils.printing import fill
+    return '\n'.join(fill(line) for line in traceback.format_exception_only(type(e), e))
+
+
 def exit_with_exc_info(code=1, message='', print_tb=False, exception=None):
     '''Exits the program, printing information about the last exception (if
     any) and an optional error message.  Uses *exception* instead if provided.
