@@ -23,6 +23,7 @@ from __future__ import print_function, unicode_literals
 import os, shutil, subprocess, re, json
 
 from ..utils.printing import (BOLD, DNANEXUS_LOGO, ENDC, fill)
+from ..cli import prompt_for_yn
 from ..compat import input, open
 
 from . import python
@@ -97,33 +98,6 @@ def prompt_for_var(prompt_str, default=None, allow_empty=False, choices=None):
         elif allow_empty:
             return value
 
-def prompt_for_yn(prompt_str, default=None):
-    if default == True:
-        prompt = prompt_str + ' [Y/n]: '
-    elif default == False:
-        prompt = prompt_str + ' [y/N]: '
-    else:
-        prompt = prompt_str + ' [y/n]: '
-
-    while True:
-        try:
-            value = input(prompt)
-        except KeyboardInterrupt:
-            print('')
-            exit(1)
-        except EOFError:
-            print('')
-            exit(1)
-        if value != '':
-            if value.lower()[0] == 'y':
-                return True
-            elif value.lower()[0] == 'n':
-                return False
-            else:
-                print('Error: unrecognized response')
-        elif default is not None:
-            return default
-
 def print_intro(api_version):
     print(DNANEXUS_LOGO() + ' App Wizard, API v' + api_version)
     print('')
@@ -300,7 +274,7 @@ def create_files_from_templates(template_dir, app_json, language,
 
     if os.path.exists(os.path.join(template_dir, 'test')):
         for template_filename in os.listdir(os.path.join(template_dir, 'test')):
-            if template_filename.endswith('~'):
+            if any(template_filename.endswith(ext) for ext in ('~', '.pyc', '.pyo')):
                 continue
             use_template_file(os.path.join('test', template_filename))
 
