@@ -91,35 +91,35 @@ from dxpy.compat import environ
 from ..exceptions import DXError
 
 
-def get_input_dir(expand_home_var=True):
+def get_input_dir(job_homedir=None):
     '''
-    :param expand_home_var: if true, expand the home directory to a full path
+    :param job_homedir: explicit value for home directory, used for testing purposes
     :rtype: string
     :returns: path to input directory
 
     Returns the input directory, where all inputs are downloaded
     '''
-    if expand_home_var:
-        home_dir = os.environ.get('HOME')
+    if job_homedir is not None:
+        home_dir = job_homedir
     else:
-        home_dir = "$HOME"
+        home_dir = os.environ.get('HOME')
     idir = os.path.join(home_dir, 'in')
     return idir
 
 
-def get_output_dir(expand_home_var=True):
+def get_output_dir(job_homedir=None):
     '''
-    :param expand_home_var: if true, expand the home directory to a full path
+    :param job_homedir: explicit value for home directory, used for testing purposes
     :rtype: string
     :returns: path to output directory
 
     Returns the output directory, where all outputs are created, and
     uploaded from
     '''
-    if expand_home_var:
-        home_dir = os.environ.get('HOME')
+    if job_homedir is not None:
+        home_dir = job_homedir
     else:
-        home_dir = "$HOME"
+        home_dir = os.environ.get('HOME')
     odir = os.path.join(home_dir, 'out')
     return odir
 
@@ -319,7 +319,8 @@ def choose_shorter_string(p, q):
         return q
     return p
 
-def analyze_bash_vars(job_input_file):
+
+def analyze_bash_vars(job_input_file, job_homedir):
     '''
     This function examines the input file, and calculates variables to
     instantiate in the shell environment. It is called right before starting the
@@ -382,7 +383,7 @@ def analyze_bash_vars(job_input_file):
     def factory():
         return {'handler': [], 'basename': [],  'prefix': [], 'path': []}
     file_key_descs = collections.defaultdict(factory)
-    rel_home_dir = get_input_dir(expand_home_var=False)
+    rel_home_dir = get_input_dir(job_homedir)
     for key, entries in file_entries.iteritems():
         for entry in entries:
             filename = entry['trg_fname']
@@ -400,9 +401,10 @@ def analyze_bash_vars(job_input_file):
 # Note: pipes.quote() to be replaced with shlex.quote() in Python 3
 # (see http://docs.python.org/2/library/pipes.html#pipes.quote)
 #
-def gen_bash_vars(job_input_file, check_name_collision=True):
+def gen_bash_vars(job_input_file, job_homedir=None, check_name_collision=True):
     """
     :param job_input_file: path to a JSON file describing the job inputs
+    :param job_homedir: path to home directory, used for testing purposes
     :param check_name_collision: should we check for name collisions?
     :return: list of lines
     :rtype: list of strings
@@ -411,7 +413,7 @@ def gen_bash_vars(job_input_file, check_name_collision=True):
     If *check_name_collision* is true, then detect and warn about
     collisions with essential environment variables.
     """
-    file_key_descs, rest_hash = analyze_bash_vars(job_input_file)
+    file_key_descs, rest_hash = analyze_bash_vars(job_input_file, job_homedir)
 
     def string_of_elem(elem):
         result = None
